==> haskell-uri-bytestring-aeson-0.1.0.9-91-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-bytestring-aeson
version:              0.1.0.9
visibility:           public
id:                   uri-bytestring-aeson-0.1.0.9-BhrXeWFoYcTAsmDzsZ3RJZ
key:                  uri-bytestring-aeson-0.1.0.9-BhrXeWFoYcTAsmDzsZ3RJZ
license:              BSD-3-Clause
maintainer:           hafnersimon@gmail.com
author:               Simon Hafner
homepage:             https://github.com/reactormonk/uri-bytestring-aeson
synopsis:             Aeson instances for URI Bytestring
category:             URI
abi:                  708cdd1210124796c87e00593ceb9d81
exposed:              True
exposed-modules:      URI.ByteString.Aeson
import-dirs:          /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring-aeson
hs-libraries:         HSuri-bytestring-aeson-0.1.0.9-BhrXeWFoYcTAsmDzsZ3RJZ
depends:
    aeson-2.1.2.1-9cza8YJPY5Z8Ze3x8zf5ig base-4.17.2.1
    bytestring-0.11.5.3 text-2.0.2
    uri-bytestring-0.3.3.1-8VqRPL6yJqSBpYxxDeMtal

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring-aeson/html/uri-bytestring-aeson.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-bytestring-aeson-0.1.0.9-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-bytestring-aeson
version:              0.1.0.9
visibility:           public
id:                   uri-bytestring-aeson-0.1.0.9-Hn3zttolDS5JHuqmv8VkeF
key:                  uri-bytestring-aeson-0.1.0.9-Hn3zttolDS5JHuqmv8VkeF
license:              BSD-3-Clause
maintainer:           hafnersimon@gmail.com
author:               Simon Hafner
homepage:             https://github.com/reactormonk/uri-bytestring-aeson
synopsis:             Aeson instances for URI Bytestring
category:             URI
abi:                  c96b244257df09200ea7f561b642037b
exposed:              True
exposed-modules:      URI.ByteString.Aeson
import-dirs:          /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring-aeson
hs-libraries:         HSuri-bytestring-aeson-0.1.0.9-Hn3zttolDS5JHuqmv8VkeF
depends:
    aeson-2.1.2.1-9cza8YJPY5Z8Ze3x8zf5ig base-4.17.2.1
    bytestring-0.11.5.3 text-2.0.2
    uri-bytestring-0.3.3.1-8CSZEt4zEzRDd64NJlBCaw

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring-aeson/html/uri-bytestring-aeson.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
